@@ -15,6 +15,16 @@ from .webkit_indexeddb import WebkitIndexedDB
 from .webkit_localstorage import WebkitLocalStorage
 from .webkit_safariviewservice import WebkitSafariViewService
 
-FS_MODULES = [CacheFiles, Filesystem, Netusage, Analytics, AnalyticsIOSVersions,
-              SafariFavicon, ShutdownLog, IOSVersionHistory, WebkitIndexedDB,
-              WebkitLocalStorage, WebkitSafariViewService]
+FS_MODULES = [
+    CacheFiles,
+    Filesystem,
+    Netusage,
+    Analytics,
+    AnalyticsIOSVersions,
+    SafariFavicon,
+    ShutdownLog,
+    IOSVersionHistory,
+    WebkitIndexedDB,
+    WebkitLocalStorage,
+    WebkitSafariViewService,
+]
