@@ -28,7 +28,7 @@ class SMSAttachments(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: bool = False,
+        module_options: Optional[dict] = None,
         log: logging.Logger = logging.getLogger(__name__),
         results: Optional[list] = None,
     ) -> None:
@@ -36,7 +36,7 @@ class SMSAttachments(IOSExtraction):
             file_path=file_path,
             target_path=target_path,
             results_path=results_path,
-            fast_mode=fast_mode,
+            module_options=module_options,
             log=log,
             results=results,
         )
@@ -54,6 +54,20 @@ class SMSAttachments(IOSExtraction):
             f"has_user_info: {record['has_user_info']})",
         }
 
+    def check_indicators(self) -> None:
+        for attachment in self.results:
+            if (
+                attachment["filename"].startswith("/var/tmp/")
+                and attachment["filename"].endswith("-1")
+                and attachment["direction"] == "received"
+            ):
+                self.log.warning(
+                    "Suspicious iMessage attachment %s on %s",
+                    attachment["filename"],
+                    attachment["isodate"],
+                )
+                self.detected.append(attachment)
+
     def run(self) -> None:
         self._find_ios_database(backup_ids=SMS_BACKUP_IDS, root_paths=SMS_ROOT_PATHS)
         self.log.info("Found SMS database at path: %s", self.file_path)
@@ -101,19 +115,6 @@ class SMSAttachments(IOSExtraction):
             attachment["has_user_info"] = attachment["user_info"] is not None
             attachment["service"] = attachment["service"] or "Unknown"
             attachment["filename"] = attachment["filename"] or "NULL"
-
-            if (
-                attachment["filename"].startswith("/var/tmp/")
-                and attachment["filename"].endswith("-1")
-                and attachment["direction"] == "received"
-            ):
-                self.log.warning(
-                    "Suspicious iMessage attachment %s on %s",
-                    attachment["filename"],
-                    attachment["isodate"],
-                )
-                self.detected.append(attachment)
-
             self.results.append(attachment)
 
         cur.close()
