@@ -28,7 +28,7 @@ class WebkitResourceLoadStatistics(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: bool = False,
+        module_options: Optional[dict] = None,
         log: logging.Logger = logging.getLogger(__name__),
         results: Optional[list] = None,
     ) -> None:
@@ -36,7 +36,7 @@ class WebkitResourceLoadStatistics(IOSExtraction):
             file_path=file_path,
             target_path=target_path,
             results_path=results_path,
-            fast_mode=fast_mode,
+            module_options=module_options,
             log=log,
             results=results,
         )
@@ -58,7 +58,7 @@ class WebkitResourceLoadStatistics(IOSExtraction):
         if not self.indicators:
             return
 
-        self.detected = {}
+        self.detected = []
         for result in self.results:
             ioc = self.indicators.check_domain(result["registrable_domain"])
             if ioc:
