@@ -23,7 +23,7 @@ class NetBase(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: bool = False,
+        module_options: Optional[dict] = None,
         log: logging.Logger = logging.getLogger(__name__),
         results: Optional[list] = None,
     ) -> None:
@@ -31,7 +31,7 @@ class NetBase(IOSExtraction):
             file_path=file_path,
             target_path=target_path,
             results_path=results_path,
-            fast_mode=fast_mode,
+            module_options=module_options,
             log=log,
             results=results,
         )
@@ -157,9 +157,9 @@ class NetBase(IOSExtraction):
             return
 
         # If we are instructed to run fast, we skip this.
-        if self.fast_mode:
+        if self.module_options.get("fast_mode", None):
             self.log.info(
-                "Flag --fast was enabled: skipping extended "
+                "Option 'fast_mode' was enabled: skipping extended "
                 "search for suspicious processes"
             )
             return
